# mclang
Create or open Minecraft: Bedrock Edition `.lang` files.

## Install
```
pip install mclang
```

## Features
- Read and write to `.lang` files.
- add translation support to your Python application.

See the docs for more information.
